@@ -1,4 +1,4 @@
-// shinyjs 0.6 by Dean Attali
+// shinyjs 0.7 by Dean Attali
 // Perform common JavaScript operations in Shiny apps using plain R code
 
 shinyjs = function() {
@@ -355,6 +355,16 @@ shinyjs = function() {
           inputType = "Checkbox";
           inputValue = input.prop('checked');
         }
+        // passwordInput
+        else if (input.children("input[type='password']").length > 0) {
+          input = input.children("input[type='password']");
+          inputType = "Password";
+        }
+        // textAreaInput
+        else if (input.children("textarea").length > 0) {
+          input = input.children("textarea");
+          inputType = "TextArea";
+        }
         // if none of the above, no supported Shiny input was found
         else {
           foundInput = false;
@@ -610,25 +620,23 @@ shinyjs = function() {
 
     html : function (params) {
       var defaultParams = {
-        id : null,
-        html : null,
-        add : false
+        id       : null,
+        html     : null,
+        add      : false,
+        selector : null
       };
       params = shinyjs.getParams(params, defaultParams);
 
-      var el = _jqid(params.id)[0];
-
-      if (typeof el === "undefined") {
-        shinyjs.debugMessage("shinyjs: element does not exist");
-        return;
-      }
-
-      if (params.add) {
-        el.innerHTML += params.html;
-      } else {
-        el.innerHTML = params.html;
-      }
+      var $els = _getElements(params);
+      if ($els === null) return;
 
+      $.each($els, function(idx, node) {
+        if (params.add) {
+          node.innerHTML += params.html;
+        } else {
+          node.innerHTML = params.html;
+        }
+      });
     },
 
     info : function (params) {
